---
title: Annotation Compass
description: A tool for gathering situated impressions in order to create individual, vernacular and poetic readings of various inputs
date: 10/12/2021
cover: 
url: /soupboat/si16/annotation-compass/
git: https://git.xpub.nl/kamo/collecting-labels
pad: https://pad.xpub.nl/p/sunday
links:
 - url: https://hub.xpub.nl/soupboat/selection-process/
   title: wip presentation
categories:
 - Web
 - SI16
 - Label
 - Tool
---


This project is a multiplayer branch of the Concrete Label tool, developed in the context of the SI16 &&& is a super collaboration with Supi, Jian, Kim, Alex, and Emma. The description is a porting of the documentation that you can find along with the various showcases on the [SI16 website](https://hub.xpub.nl/soupboat/si16/projects/annotation-compass/).

How do we bring multi-vocality in the work of annotation? The Annotation Compass builds composites from aggregated vernacular impressions, rich of their subjectivity and situatedness. It is the outcome of a three months journey questioning the relationship between vernacular languages and natural language processing tools. 

## First Experiments

### The living-room

![Supi's livingroom](/soupboat/~kamo/static/img/map_description_H.jpg)

For this experiment, four of us were gathered in a living-room.

- Number of participants: 4
- Location: Supi's living room
- Aim: Map out each participant's impressions of the living room.
- Material: The living room's floor plan, InDesign, computers.....
- Time-frame: 5 minutes
- Instructions: individually annotate the floor plan with impressions of the living room

After removing the floor plan and looking at the subjective annotations of this experiment, we observed that each outcome forms another 'space'. Each person's set of annotations brings a unique perspective of the living room , an 'individual map'. We then layered the individual maps and the compilation resulted in a vernacular picture of the space. This alternative understanding of the space can only be given to a reader through those descriptions.

### Still from Michael Snow's Wavelength

![Michael Snow, Wavelength](https://pzwiki.wdka.nl/mw-mediadesign/images/3/3e/Selection_process_2.png)

The same method was applied to the photograph of a room. Each of us used a different set of coloured sticky notes and took 5 minutes to physically annotate the picture on the same surface. The picture was then removed from the background, resulting in a similar outcome as the experiment described above.

From these observations, our interest on subjective annotations that could flow in a common understanding of an image grew. As a tool to collect situated impressions, we elaborated the idea of the Annotation Compass.

On a given surface, such as an image, the tool facilitates the collection of annotations and their coordinates from various users simultaneously. These annotations represent individual knowledges and perspectives in regards to the given surface.

![Michael Snow, Wavelength](https://pzwiki.wdka.nl/mw-mediadesign/images/3/32/Selection_process_3.png)
![Michael Snow, Wavelength](https://pzwiki.wdka.nl/mw-mediadesign/images/2/2b/Selection_process_4.png)

## Instructions

To use this tool, let's consider the "host" any person interested in gathering annotation on a specific image; and the "guest" any person invited by the host to annotate the image.

### Process for the host

1. upload an image
2. add a text to explain the context of the image or to give instructions and helpful advice to the guests
3. send link to guests and invite them to annotate
4. download a json-file or text-file that contains the collected data that was gathered so far
5. try the different functions of SI16 to filter the collected dat

### Process for the guest

1. open the link sent by the host
2. read the information attached to the image by the host
3. use the cursor to select a specific area that you want to annotate
4. write and insert your annotation(s)a

## The data

The Tool not only archives the annotations, but also additional meta-data that can be helpful to analyze the outcome. The collected data is stored in a "json-file" that comes as a list of labels. In each label, one can find the file name of the annotated image, the coordinates of the annotation, the dimension of the annotation 'box', the annotation itself, the index number of the annotation and a user identification:

```json
{
    "image": "filename.jpg",
    "position": {"x": 12, "y": 97},
    "size": {"width": 43, "height": 18},
    "text": "Content of the annotation",
    "timestamp": "Wed, 01 Dec 2021 14:04:00 GMT",
    "userID": 123456789
}
```

- `image`: a reference to the filename of the image
- `position`: x and y coordinates given in percentage, relative to the top left corner of the image
- `size`: width and height given in percentage, relative to the size of the image
- `text`: the text content of the label
- `timestamp`: the moment in which the label was uploaded
- `userID`: a random generated id to keep track of the autorship of the labels

__for the future:__ at some point could be intresting to something like a `components` property, in order to make the tool more flexible and open to plugin or integration. Ideally this property is a list of components, and each one can add some kind of info or metadata for specific usecases, without the need to rewrite all the code to make room for that.  

The outcome provided by the Annotation Compass is ever-changing: whenever an individual adds an annotation, the data grows.

After applying the tool to different projects we observed that the collected data can offer a reflexion on the so called "objective": It provides individual perceptions and builds a common experience by including a multiplicity of impressions rather than one objective definition. In conclusion, the Tool can be used to provide alternative ways to define images, images of space, texts, and anything else annotatable.

## Possible applications of the tool:

- Ask individuals to annotate the space they are in at the moment.
- Ask individuals to annotate a space from memory.
- Ask individuals to annotate imaginary spaces. (e.g. a space from a dream, a fictional space they know from a novel, a place that exists but they never went …)
- Ask individuals to annotate a space before and after they went for the first time.
- Invite individuals to a space and ask them to annotate it as a performative act that is situated not only in space but also time.
- Ask individuals to annotate a space whenever they want (unlimited access).
- Ask individuals to annotate a public space.
- Ask individuals to annotate a whole city, country, continent …
- Ask individuals to annotate a private space.
- Ask individuals to annotate an indoor space (bedroom, library, central station, theatre …)
- Ask individuals to annotate an outdoor space (park, market place, beach …)
- Ask specific groups to annotate a space (queer, teenagers, people with disabilities, immigrants …)
- Ask individuals to annotate specific things, e.g. emotions, colors, surfaces, light …
- Ask individuals to only use specific glyphs (e.g. ! ? and –) or emojis to annotate the space to include those not confident using words.
- Encourage individuals to use their mother tongue / slang / informal language to annotate a space.
- Ask only one individual to give many annotations of a space over time (daily diary, yearly check-in …)
- Ask individuals to annotate different spaces (e.g. their own living rooms)
- Ask individuals to annotate a space without using a standard map but rather an empty sheet as a starting point.
- Ask individuals to annotate a space without using a standard map but rather an individual map or vernacular map as a starting point.
- Ask individuals to annotate a space without using a standard map but rather a photograph of a space as a starting point.
- Ask individuals to annotate a space in real life (e.g. using sticky notes, writing on plexiglass, interview) and use the tool to insert the data afterwards.
- annotate a photograph (portrait, scene, landscape …)
- annotate a painting
- annotate a text
- annotate a song/sound
- misusing the tool
