---
title: SI16 Structure Proposal
description: Imaging the SI16 as an API ecosystem
date: 15/11/2021
pad: https://pad.xpub.nl/p/SP16_totemical_magic_sorcery
links:
 - url: https://www.figma.com/file/y0nfu3v9YHzUV5WtUOC0Fo/?node-id=840%3A51
   title: Figma
categories:
 - SI16
 - Proposal
css: structure-proposal.css
---

## Overview

The special issue is composed of three main parts: the library, the projects and the launch event. Each one of these has a slightly different nature, and so can access to different kinds of public. 
Imaging the SI16 as an ecosystem around these three faces permits us to create an organic form of public: someone comes for the event and discovers an API, someone else arrives from the code and is introduced to the critical context around it, each project tho is situated in a specific thematic niche and the interactions with the whole ecosystem could provide fresh air to spin  mill. 

A systematic approach in the contents' structure enables us to morph our projects without sacrifice the unique nature of each work. What's more is that with a clear data structure we can deliver contents in different forms with less effort and less stress.

The following structure is a draft. The order of the elements is not defined nor fixed. Some things are not mandatory, but would be nice and useful to have them if we think to the future life of the SP16 after the launch. The idea is to build something easy to scale, to expand, and to update. Something easy to participate. As an ecosystem some parts are more likely to grow and to evolve, and to provide a good soil as starting point maybe is the best thing we can do? 

## 1. Library
### A collection of modules and tools within a context

The library is the main container of the SP16. It provides a list of algorithms and describes the world in which they operate. This world is our source of truth: it is built from all the corpora we will aggregate and use for the projects, as well as other critical contributions, inquiries about the vernacular, and guide to navigate through all the materials. Ultimately a library, or a toolkit, is orientated. Its political stance stands not only in its contents, but also in the way it grants access to them. The relation between authors and public is not based only on power, but here also in trust, and collaboration, and dependency, and mutuality. 

Hence the library is part contents, part tools, part documentation, part showcase. These sections could be open and do not have to be perceived as finished. A library is always a work in progress, a work that we are starting now, a work that then someone else can continue.

Beside the contents and their structure, the library also include a showcase section to display all the projects we are working on now. This section strengths the link between the special issue as a publication and the special issue as an event. In order to preserve the original approach of each project an in depth record of each work is provided here. It is perceived as something sprouting from the library. Are the projects and the special issue publication the same thing? Maybe not, but for sure they are deeply related.

![Library](/soupboat/~kamo/static/img/lib-structure.svg)

-   **Title**, The name of the library
-   **Description**, An overview of what it does, how and why does it exist
-   **Context**, A collection of materials (researches, essays, excerpts, ...) that situate this library in relation with the vernacular
    -   **Manifesto**, Our attitude, our purposes, our plan. It could work as an introduction to the special issue
        -   **Our plan**, A summary of the research in terms of intentions
        -   **Our attitude**, An overview of the different approaches we used
        -   **Our purposes**, What do we want to achieve or encourage
    -   **Materials - Corpora**, Collections of materials used as sources or collected for the projects
        -   **Corpus**, Single corpus of materials used as sources for the projects
            -   **Title**, A title for the corpus
            -   **Description**, An overview of the contents and how they are structured
            -   **Type**, The kind of materials included
            -   **Structure**, A description of the structure of the contents
            -   **Contents**, List of contents
        -   **...**, [...other corpus in the list]
    -   **Research and Development**, A collection of contribuitions (researches, essays, excerpts, ...) that situate this library in relation with the vernacular
        -   **SP16 History**, Evolution of the SP16 work, devlog, excerpts from the pads, etc
        -   **List of contribuitions**, Collection of essays, excerpts from the texts read in class, piece from the tutors, from us, etc
            -   **Contribuition**, Single contribuition in the list
                -   **Title**, Title of the contribuition
                -   **Description**, Description of the contribution
                -   **Subject**, Theme of the contribution
                -   **Contents**, Contents of the contribuition
                -   **Credits**, Credits and references
            -   **...**, [...other contribuitions in the list]
    -   **Guide**, Presentation of the form of the SI16 and its structure, how to read it and navigate it
        -   **Getting started**, First steps into the SP16 as an API
        -   **What is a documentation**, How the documentation is structured
        -   **Learning how to walk while catwalking**, Navigation through the special issue
-   **Showcase - List of Projects Documentations**S, howcase of full fledged and meaningful project built within and from the library, list of projects documentations
    -   **Project Documentation**, Documentation of a project
        -   **Contents**, Extended description of the project, including the research, the process and the future possibilities
            -   **Research**, Background of the work, field of intrests, ideas, theory, etc
            -   **Process**, History of the work, process of development, prototyping, etc
            -   **Outcomes**, Results of the research and synthesis of the process
            -   **Direction**, Possibilities for the evolution of the project, new applications, ideas, findings
        -   **Documentation**, Nice showcase of the work
            -   **Text**, Textual description of project and key findings
            -   **Visual**, Visual documentation such as pictures, videos, etc
            -   **\***, Other specifications are unique for each project
        -   **References**, Reference to the corpora or materials used and to the tool involved during the production
            -   **Materials**, Corpora and sources used or created for the project
            -   **Theory**, References for specific theoric notes
            -   **Codes**, Modules, functions and parts of the library involved in the work
    -   **...**, [...other projects documentations in the showcase]
-   **List of Modules**, A list of all the different code approaches, or modules, that compose the library
    -   **Module**, A thematic or reasoned group of functions
        -   **Title**, The name of the module
        -   **Decription**, A description of what it does
        -   **Applications**, Examples of applications that use several functions to build complex procedures
        -   **List of functions**, A list of functions
            -   **Function**, A single function in the module
                -   **Title**, The name of the function or algorithm
                -   **Description**, A description of what it does
                -   **Input**, The types of inputs it receives
                -   **Codes**, The procedure it follows
                -   **Output**, The types of outputs it returns
                -   **Example**, Simple and specific examples
            -   **...**, [...other functions in the module]
        -   **...**, [...other modules in the library]
        
## 2. Project
### Full fledged and meaningful work built within and from the library

The main feature of having several serious different projects is both that we can explore different shades of the vernacular language processing and that we can access to different kinds of public. It is true that we are in needs for more time now, but at the same time having different projects to work on 


![Library](/soupboat/~kamo/static/img/proj-structure.svg)

-   **Title**, Title of the project
-   **Description**, Description of the project
-   **Colophon**, Credits and colophon
-   **Project Object**, Concrete outcomes of the project
    -   **Object**, Concrete result of the work
    -   **\***, Specifications are unique for each project
-   **Project Documentation**, Documentation of the project
    -   **Contents**, Extended description of the project, including the research, the process and the future possibilities
        -   **Research**, Background of the work, field of intrests, ideas, theory, etc
        -   **Process**,History of the work, process of development, prototyping, etc
        -   **Outcomes**, Results of the research and synthesis of the process
        -   **Direction**, Possibilities for the evolution of the project, new applications, ideas, findings
    -   **Documentation**,Nice showcase of the work
        -   **Text**, Textual description of project and key findings
        -   **Visual**,Visual documentation such as pictures, videos, etc
        -   **\***, Other specifications are unique for each project
    -   **References**, Reference to the corpora or materials used and to the tool involved during the production
        -   **Corpora**, Corpora and sources used or created for the project
        -   **Theory/contributions**,References for specific theoric notes
        -   **Codes**, Modules, functions and parts of the library involved in the work


## 3. Launch 
### @Varia on 17.12.2021

![Library](/soupboat/~kamo/static/img/launch-structure.svg)

-   **Space setup**, Display and physical setup of the space
-   **List of presentations**, List of moments in which the different contents of the SP16 are presented to the public
    -   **Presentation**, Moment like performance, presentation, talk, workshop, panel, etc
        -   **Title**, Title of the presentation
        -   **Description**, Description of the presentation
        -   **Subject**, Theme of the contribution
        -   **Type**, Kind of presentation: talk, panel, showcase of a project, performance, etc
        -   **Contents**, Contents and theme of the presentation
    -   **...**, [...other presentations in the list]
-   **List of projects objects**, List of physical outcomes from the projects
    -   **Project Object**, Concrete outcomes of the project
        -   **Object**, Concrete result of the work
        -   **\***, Specifications are unique for each project
    -   **...**, [...other project object in the list]